The EQ5D.be package provides functions to calculate Belgian index values and population norms for the EuroQol 5 Dimensions questionnaire.
| Package: | EQ5D.be |
| Type: | Package |
| Version: | 0.1.0 |
| Date: | 2021-07-01 |
| Authors: | Brecht Devleesschauwer |
| Maintainer: | Brecht Devleesschauwer <brechtdv@gmail.com> |
| Depends: | R (>= 4.1.0) |
| License: | GPL (>= 2) |
Available functions in the EQ5D.be package:
| Index values | |
index3L | Calculate index values for the EQ-5D-3L descriptive system. |
index5L | Calculate index values for the EQ-5D-5L descriptive system. |
| Population norms | |
popnorm | Population norms for the EQ-5D-5L and EQ-5D VAS instruments. |
popnormINDEX | Population norms for the EQ-5D-5L index score. |
popnormVAS | Population norms for the EQ-5D-5L visual analogue scale. |
popnormMO | Population norms for reporting any problems of mobility. |
popnormSC | Population norms for reporting any problems of self-care. |
popnormUA | Population norms for reporting any problems with performing usual activities. |
popnormPD | Population norms for reporting any problems of pain/discomfort. |
popnormAD | Population norms for reporting any problems of anxiety/depression. |
popnormANY | Population norms for reporting any problem in the EQ-5D-5L descriptive system. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.